@@ -1,16 +1,10 @@
-from enum import Enum
-from os import wait
-from time import sleep, time
-from selve import commands
 from selve.device import Device
 
-from selve.protocol import CommandTypeIveo, CommunicationType, DeviceClass, ErrorResponse, MethodCall, RepeaterState
+from selve.protocol import CommandTypeIveo, CommunicationType, DeviceClass, MethodCall, RepeaterState
 from selve.protocol import ParameterType
 from selve.protocol import DeviceType
-from selve.protocol import CommandType
-from selve.commands import Commands, IveoCommand
+from selve.commands import IveoCommand
 from selve.communication import Command, CommandMask, CommandSingle
-from selve.utils import singlemask
 from selve.utils import true_in_list
 from selve.utils import b64bytes_to_bitlist
 import logging
